from logger_local.LoggerComponentEnum import LoggerComponentEnum


class CSVToContactPersonProfileConstants:
    CSV_LOCAL_PYTHON_COMPONENT_ID = 198
    CSV_LOCAL_PYTHON_COMPONENT_NAME = 'contact-person-profile-csv-imp-local-python-package'
    DEVELOPER_EMAIL = "tal.g@circ.zone"
    CSV_LOCAL_PYTHON_PACKAGE_CODE_LOGGER_OBJECT = {
        'component_id': CSV_LOCAL_PYTHON_COMPONENT_ID,
        'component_name': CSV_LOCAL_PYTHON_COMPONENT_NAME,
        'component_category': LoggerComponentEnum.ComponentCategory.Code.value,
        'developer_email': DEVELOPER_EMAIL
    }

    CSV_LOCAL_PYTHON_PACKAGE_TEST_LOGGER_OBJECT = {
        'component_id': CSV_LOCAL_PYTHON_COMPONENT_ID,
        'component_name': CSV_LOCAL_PYTHON_COMPONENT_NAME,
        'component_category': LoggerComponentEnum.ComponentCategory.Unit_Test.value,
        'testing_framework': LoggerComponentEnum.testingFramework.pytest.value,
        'developer_email': DEVELOPER_EMAIL
    }

    # TODO search for the source_type_id in the database and remove those constants
    GOOGLE_CSV_DATA_SOURCE_TYPE_ID = 16
    LINKEDIN_CSV_DATA_SOURCE_TYPE_ID = 18
    OUTLOOK_CSV_DATA_SOURCE_TYPE_ID = 17
    BGU_COURSE_CSV_DATA_SOURCE_TYPE_ID = 57
    RISHON_MUNI_EXHIBITOR_CSV_DATA_SOURCE_TYPE_ID = 60



import setuptools

PACKAGE_NAME = 'contact-person-profile-csv-imp-local'
package_dir = PACKAGE_NAME.replace("-", "_")

setuptools.setup(
    name=PACKAGE_NAME,
    version='0.0.61b2884',  # https://pypi.org/project/contact-person-profile-csv-imp-local/

    author="Circles",
    author_email="info@circles.ai",
    description="PyPI Package for Circles csv_to_contact_person_profile-local Local/Remote Python",
    long_description="This is a package for sharing common XXX function used in different repositories",
    long_description_content_type="text/markdown",
    packages=[package_dir],
    package_dir={package_dir: f'{package_dir}/src'},
    package_data={package_dir: ['*.py']},
    url=f"https://github.com/circles-zone/{PACKAGE_NAME}-python-package",
    classifiers=[
        "Programming Language :: Python :: 3",
        # "License :: Other/Proprietary License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'contact-local>=0.0.48',
        'logger-local>=0.0.135',
        'database-mysql-local>=0.1.1',
        'user-context-remote>=0.0.77',
        'contact-email-address-local>=0.0.40.1234',
        'contact-group-local>=0.0.68',
        'contact-location-local>=0.0.14',
        'contact-notes-local>=0.0.33',
        'contact-persons-local>=0.0.8',
        'contact-phone-local>=0.0.12',
        'contact-profile-local>=0.0.7',
        'contact-user-external-local>=0.0.13',
        'importer-local>=0.0.54',
        'internet-domain-local>=0.0.8',
        'location-local>=0.0.104',
        'organization-profile-local>=0.0.4',
        'organizations-local>=0.0.14',
        'python-sdk-remote>=0.0.93',
        'url-remote>=0.0.91',
        'user-external-local>=0.0.114',
        'chardet>=5.2.0'
    ]
)
